Регистрация | OiRA

Теми

# Регистрация

## Защо трябва да се регистрирам?

Преди да започнете първата си оценка на риска, трябва да си създадете потребителски акаунт в OiRA — процедурата е лесна и бърза.

Регистрацията ще ви позволи да влизате в системата по всяко време, за да получите достъп до вашите данни, да продължите вече започнати оценки или да стартирате нови.

След като се регистрирате, можете да разчитате, че системата OiRA ще съхрани всички ваши потребителски сесии и данните ви ще бъдат достъпни по всяко време.

Запознайте се с нашата политика за поверителност и с информация за това как обработваме вашите лични данни.

## Каква е разликата между регистрацията като потребител и използването на тестова сесия?

Тестовата сесия позволява на заинтересованите лица да се запознаят с инструмента, преди да вземат решение дали да се регистрират. В рамките на тестовата сесия данните ви няма да бъдат съхранени и няма да можете на по-късен етап да получите достъп до информацията, която сте въвели. Тестовата сесия не ви позволява да разпечатате доклади, но ако регистрирате потребителски акаунт, ще можете да документирате изцяло оценката на риска.

## Регистрирайте нов акаунт

Това първото ви посещение ли е? Изпълнете следните прости стъпки, за да започнете регистрацията:

1.) Щракнете върху бутона „Регистрация“, за да се отвори формулярът за регистрация.

Формуляр за регистрация

2.) Въведете адрес за електронна поща и изберете парола (въвежда се два пъти);

3.) Щракнете върху бутона „Напред“, за да регистрирате нов акаунт;

4.) Прочетете и приемете нашата политика за поверителност, за да продължите напред.

След това влизате в системата OiRA.

## Вход със съществуващ акаунт

Ако вече сте регистрирани, влезте в акаунта си по следния начин:

1.) Отворете формуляра за вход. Връзка към формуляра е достъпна винаги, когато се опитвате да получите достъп до OiRA, и до момента на влизане в системата.

Формуляр за вход

2.) Попълнете вашия адрес за електронна поща и парола;

3.) Влезте в системата, като щракнете върху бутона „Вход“.

След като влезете в системата, ще се отвори показаният по-долу екран. Оттук можете да стартирате нова оценка на риска или да се върнете към оценки на риска, които сте започнали по-рано.

Информационно табло

Стартирайте нова оценка на риска, като изберете име на оценката (напр. „Моето дружество 7.3.2018“), или отворете една от вече започнатите оценки. Всичките ви оценки се съхраняват за бъдеща справка, освен ако не решите да ги изтриете.

Scroll to top Load toolbar…
Back

## 1-registration.md

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More